@@ -1,4 +1,4 @@
-from pydantic import BaseModel
+from .base import BaseModel
 
 
 class OIDCTestReq(BaseModel):
